/// <reference types="node" />
import * as superagent from 'superagent';
import * as moment from 'moment';
export interface IHiveMPClient {
    apiKeyFactory: () => string;
    baseUrlFactory: () => string;
    getOriginalApiId: () => string;
    getOriginalBasePath: () => string;
    invocationWrapper: HiveMPInvocationWrapper<any> | null;
}
export interface PaginatedResults<T> {
    next: string | null;
    moreResults: boolean;
    results: T[];
}
export interface HiveMPInvocationWrapper<T> {
    (methodToInvoke: () => Promise<T>): Promise<T>;
}
export interface HiveMPClientConstructable {
    new (apiKey?: (string | (() => string))): IHiveMPClient;
}
export declare class HiveMPError extends Error {
    _hiveMPErrorType: string;
    redirectTarget?: string;
    apiError?: HiveMPSystemError;
    nestedErr?: any;
}
export interface HiveMPSystemErrorWithTimeout extends HiveMPSystemError {
    isTimeout: boolean;
}
export declare class HiveMPErrorFactory {
    static createRedirectError(redirectTarget: string): Error;
    static isRedirectError(err: any): boolean;
    static getRedirectErrorRedirect(err: any): string;
    static createApiError(apiError: HiveMPSystemError): Error;
    static isApiError(err: any): boolean;
    static getApiErrorData(err: any): HiveMPSystemErrorWithTimeout;
    static createSessionExpiredError(): Error;
    static isSessionExpiredError(err: any): boolean;
    static createClientError(response: superagent.Response): Error;
    static isClientError(err: any): boolean;
    static createUnknownError(nestedErr: any): Error;
    static isUnknownError(err: any): boolean;
}
export interface HiveMPSystemError {
    code: number | null;
    message: string | null;
    fields: string | null;
    data: HiveMPSystemErrorData | null;
}
export interface HiveMPSystemErrorData {
    invalidSessionId?: string | null;
    expectedSessionType?: string | null;
    parameterName?: string | null;
    parameterInvalidReason?: string | null;
    parameterIsMissing?: boolean | null;
    objectType?: string | null;
    objectContext?: string | null;
    objectNotEditableReason?: string | null;
    invalidIdentifier?: string | null;
    invalidIdentifierReason?: string | null;
    invalidIdentifierExpectedType?: string | null;
    invalidConfigurationReason?: string | null;
    amount?: number | null;
    amountFractionalDivisor?: number | null;
    internalSentryErrorId?: string | null;
    internalExceptionMessage?: string | null;
    internalExceptionStackTrace?: string | null;
    unauthorizedAdditionalInfo?: string | null;
    queryFailureCode?: number | null;
    queryFailureMessage?: string | null;
    queryFailureErrors?: HiveMPSystemQueryError[] | null;
}
export interface HiveMPSystemQueryError {
    domain: string | null;
    location: string | null;
    locationType: string | null;
    message: string | null;
    reason: string | null;
}
export declare namespace AdministrativeSession {
    interface AdminSession {
        id: string | null;
        username: string | null;
        gravatarHash: string | null;
        dateUserCreatedUtc: moment.Moment | null;
        expiry: number | null;
        project: string | null;
    }
    interface AdminSessionWithSecrets {
        id: string | null;
        username: string | null;
        gravatarHash: string | null;
        dateUserCreatedUtc: moment.Moment | null;
        expiry: number | null;
        project: string | null;
        apiKey: string | null;
        secretKey: string | null;
    }
    interface AdminUserSummary {
        username: string | null;
    }
    interface NewsItem {
        dateAuthoredUtc: moment.Moment | null;
        title: string | null;
        url: string | null;
    }
    interface Project {
        id: string | null;
        name: string | null;
        active: boolean | null;
        billingAccountId: string | null;
        delinquent: boolean | null;
        isTestProject: boolean | null;
        discoverable: boolean | null;
        publicName: string | null;
        websiteUrl: string | null;
        websiteVerified: boolean | null;
        developerName: string | null;
        shortDescription: string | null;
        bannerUrl: string | null;
        avatarUrl: string | null;
    }
    interface ProjectPublic {
        id: string | null;
        name: string | null;
        websiteUrl: string | null;
        websiteVerified: boolean | null;
        developerName: string | null;
        shortDescription: string | null;
        avatarUrl: string | null;
        bannerUrl: string | null;
    }
    interface ProjectAccessEntry {
        type: string | null;
        username: string | null;
        projectId: string | null;
        projectName: string | null;
    }
    class AdministrationSessionClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        sessionGET(req: sessionGETRequest): Promise<AdminSession>;
        private __sessionGET;
        sessionPUT(req: sessionPUTRequest): Promise<AdminSessionWithSecrets>;
        private __sessionPUT;
        sessionPOST(req: sessionPOSTRequest): Promise<AdminSession>;
        private __sessionPOST;
        sessionDELETE(req: sessionDELETERequest): Promise<boolean>;
        private __sessionDELETE;
        switchPUT(req: switchPUTRequest): Promise<AdminSessionWithSecrets>;
        private __switchPUT;
    }
    interface sessionGETRequest {
        id: string;
    }
    interface sessionPUTRequest {
        username: string;
        password: string;
        project?: string;
    }
    interface sessionPOSTRequest {
    }
    interface sessionDELETERequest {
        id: string;
    }
    interface switchPUTRequest {
        id: string;
    }
    class AdministrationUserClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        userGET(req: userGETRequest): Promise<AdminUserSummary>;
        private __userGET;
        userPUT(req: userPUTRequest): Promise<AdminUserSummary>;
        private __userPUT;
        verifyPOST(req: verifyPOSTRequest): Promise<AdminUserSummary>;
        private __verifyPOST;
    }
    interface userGETRequest {
        username?: string;
    }
    interface userPUTRequest {
        username: string;
        password: string;
        email: string;
    }
    interface verifyPOSTRequest {
        username?: string;
        code?: string;
    }
    class NewsClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        newsRecentGET(req: newsRecentGETRequest): Promise<NewsItem[]>;
        private __newsRecentGET;
    }
    interface newsRecentGETRequest {
    }
    class ProjectInfoClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        projectsGET(req: projectsGETRequest): Promise<Project[]>;
        private __projectsGET;
        projectGET(req: projectGETRequest): Promise<Project>;
        private __projectGET;
        projectPUT(req: projectPUTRequest): Promise<Project>;
        private __projectPUT;
        projectPOST(req: projectPOSTRequest): Promise<Project>;
        private __projectPOST;
        projectBannerPUT(req: projectBannerPUTRequest): Promise<Project>;
        private __projectBannerPUT;
        projectAvatarPUT(req: projectAvatarPUTRequest): Promise<Project>;
        private __projectAvatarPUT;
        projectPublicGET(req: projectPublicGETRequest): Promise<ProjectPublic>;
        private __projectPublicGET;
        projectsPublicGET(req: projectsPublicGETRequest): Promise<ProjectPublic[]>;
        private __projectsPublicGET;
        accessGET(req: accessGETRequest): Promise<ProjectAccessEntry[]>;
        private __accessGET;
        accessUserPUT(req: accessUserPUTRequest): Promise<boolean>;
        private __accessUserPUT;
        accessUserDELETE(req: accessUserDELETERequest): Promise<boolean>;
        private __accessUserDELETE;
        accessProjectPUT(req: accessProjectPUTRequest): Promise<boolean>;
        private __accessProjectPUT;
        accessProjectDELETE(req: accessProjectDELETERequest): Promise<boolean>;
        private __accessProjectDELETE;
    }
    interface projectsGETRequest {
    }
    interface projectGETRequest {
        id: string;
    }
    interface projectPUTRequest {
        name: string;
        discoverable?: boolean;
        isTestProject?: boolean;
        publicName?: string;
        shortDescription?: string;
        developerName?: string;
    }
    interface projectPOSTRequest {
        id: string;
        name?: string;
        active?: boolean;
        discoverable?: boolean;
        publicName?: string;
        websiteUrl?: string;
        shortDescription?: string;
        developerName?: string;
    }
    interface projectBannerPUTRequest {
        id: string;
        content: Buffer | ArrayBuffer;
    }
    interface projectAvatarPUTRequest {
        id: string;
        content: Buffer | ArrayBuffer;
    }
    interface projectPublicGETRequest {
        id?: string;
    }
    interface projectsPublicGETRequest {
        ids: string[];
    }
    interface accessGETRequest {
        id: string;
    }
    interface accessUserPUTRequest {
        id: string;
        username: string;
    }
    interface accessUserDELETERequest {
        id: string;
        username: string;
    }
    interface accessProjectPUTRequest {
        id: string;
        projectId: string;
    }
    interface accessProjectDELETERequest {
        id: string;
        projectId: string;
    }
}
export declare namespace ApiKey {
    interface PaginatedApiKeys {
        next: string | null;
        moreResults: boolean;
        results: ApiKey[];
    }
    interface ApiKey {
        type: string | null;
        comment: string | null;
        apiKeyHash: string | null;
        adminUser: string | null;
        sessionId: string | null;
        accountId: string | null;
        dateCreatedUtc: moment.Moment | null;
        dateModifiedUtc: moment.Moment | null;
    }
    interface RevealedApiKey {
        apiKey: string | null;
    }
    class KeyClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        keysGET(req: keysGETRequest): Promise<PaginatedApiKeys>;
        private __keysGET;
        keysAdminUserGET(req: keysAdminUserGETRequest): Promise<PaginatedApiKeys>;
        private __keysAdminUserGET;
        keysAccountGET(req: keysAccountGETRequest): Promise<PaginatedApiKeys>;
        private __keysAccountGET;
        keyGET(req: keyGETRequest): Promise<ApiKey>;
        private __keyGET;
        keyPOST(req: keyPOSTRequest): Promise<ApiKey>;
        private __keyPOST;
        keyDELETE(req: keyDELETERequest): Promise<ApiKey>;
        private __keyDELETE;
        revealPUT(req: revealPUTRequest): Promise<RevealedApiKey>;
        private __revealPUT;
        keyPublicPUT(req: keyPublicPUTRequest): Promise<ApiKey>;
        private __keyPublicPUT;
    }
    interface keysGETRequest {
        start?: string;
        limit?: number;
        type: string;
    }
    interface keysAdminUserGETRequest {
        start?: string;
        limit?: number;
        username: string;
    }
    interface keysAccountGETRequest {
        start?: string;
        limit?: number;
        accountId: string;
    }
    interface keyGETRequest {
        apiKeyHash: string;
    }
    interface keyPOSTRequest {
        apiKeyHash: string;
        comment?: string;
    }
    interface keyDELETERequest {
        apiKeyHash: string;
    }
    interface revealPUTRequest {
        apiKeyHash: string;
    }
    interface keyPublicPUTRequest {
        comment?: string;
    }
}
export declare namespace Chat {
    interface ChatSendMessage {
        rid: string | null;
        sts: number | null;
        msg: string | null;
    }
    interface CreateGroupMessage {
        ids: string[] | null;
    }
    interface GetGroupMessage {
        id: string | null;
        ids: string[] | null;
    }
    interface ChatReceiveMessage {
        id: string | null;
        rid: string | null;
        sts: number | null;
        sid: string | null;
        msg: string | null;
    }
    interface GroupInfoMessage {
        id: string | null;
        t: string | null;
        ids: string[] | null;
    }
    class ChatClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        chatConnectGET(req: chatConnectGETRequest): Promise<void>;
        private __chatConnectGET;
    }
    interface chatConnectGETRequest {
    }
}
export declare namespace EventTracking {
    interface EventType {
        id: string | null;
        currentVersion: string | null;
        name: string | null;
        description: string | null;
    }
    interface EventTypeBase {
        name: string | null;
        description: string | null;
    }
    interface EventTypeVersion {
        eventTypeName: string | null;
        eventTypeVersion: string | null;
        status: 'pending' | 'creating' | 'creation-error-retryable' | 'creation-error-permanent' | 'updating' | 'update-error-retryable' | 'update-error-permanent' | 'available' | null;
        statusDetailed: string | null;
        eventTypeId: string | null;
        changeNotes: string | null;
        schema: EventSchema | null;
        partitioning: EventTypeVersionPartitioning | null;
    }
    interface EventSchema {
        fields: EventSchemaField[] | null;
    }
    interface EventTypeVersionPartitioning {
        enabled: boolean | null;
        automaticExpirationEnabled: boolean | null;
        automaticExpirationDays: number | null;
        fieldName: string | null;
        requirePartitionFilterInQueries: boolean | null;
    }
    interface EventSchemaField {
        name: string | null;
        type: 'int64' | 'float64' | 'numeric' | 'bool' | 'string' | 'bytes' | 'date' | 'datetime' | 'time' | 'timestamp' | 'array' | 'struct' | 'userAccountId' | 'sessionId' | 'approximateGeographicLocation' | 'currentUtcTimestamp' | null;
        arrayMemberType: 'int64' | 'float64' | 'numeric' | 'bool' | 'string' | 'bytes' | 'date' | 'datetime' | 'time' | 'timestamp' | 'array' | 'struct' | 'userAccountId' | 'sessionId' | 'approximateGeographicLocation' | 'currentUtcTimestamp' | null;
        structFields: EventSchemaField[] | null;
    }
    interface EventTypeVersionBase {
        eventTypeId: string | null;
        changeNotes: string | null;
        schema: EventSchema | null;
        partitioning: EventTypeVersionPartitioning | null;
    }
    class EventClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        eventInsertPUT(req: eventInsertPUTRequest): Promise<boolean>;
        private __eventInsertPUT;
        eventBatchInsertPUT(req: eventBatchInsertPUTRequest): Promise<boolean>;
        private __eventBatchInsertPUT;
    }
    interface eventInsertPUTRequest {
        eventType?: string;
        eventTypeVersion?: string;
        event?: any;
    }
    interface eventBatchInsertPUTRequest {
        eventType?: string;
        eventTypeVersion?: string;
        events?: any;
    }
    class EventTypesClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        typesGET(req: typesGETRequest): Promise<PaginatedResults<EventType>>;
        private __typesGET;
        typeGET(req: typeGETRequest): Promise<EventType>;
        private __typeGET;
        typePUT(req: typePUTRequest): Promise<EventType>;
        private __typePUT;
        typePOST(req: typePOSTRequest): Promise<EventType>;
        private __typePOST;
        typeVersionsGET(req: typeVersionsGETRequest): Promise<PaginatedResults<EventTypeVersion>>;
        private __typeVersionsGET;
        typeVersionGET(req: typeVersionGETRequest): Promise<EventTypeVersion>;
        private __typeVersionGET;
        typeVersionPUT(req: typeVersionPUTRequest): Promise<EventTypeVersion>;
        private __typeVersionPUT;
        typeVersionPOST(req: typeVersionPOSTRequest): Promise<EventTypeVersion>;
        private __typeVersionPOST;
    }
    interface typesGETRequest {
        start?: string;
        limit?: number;
    }
    interface typeGETRequest {
        id: string;
    }
    interface typePUTRequest {
        eventType?: EventTypeBase;
    }
    interface typePOSTRequest {
        eventType?: EventType;
    }
    interface typeVersionsGETRequest {
        id: string;
        start?: string;
        limit?: number;
    }
    interface typeVersionGETRequest {
        id: string;
        version: string;
    }
    interface typeVersionPUTRequest {
        eventTypeVersion?: EventTypeVersionBase;
    }
    interface typeVersionPOSTRequest {
        eventTypeVersion?: EventTypeVersion;
    }
}
export declare namespace Scheduling {
    interface ScheduledCallback {
        callbackUrl: string | null;
        scheduleUtc: moment.Moment | null;
    }
    interface FireResult {
        success: boolean | null;
    }
    class SchedulingClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        schedulePUT(req: schedulePUTRequest): Promise<ScheduledCallback>;
        private __schedulePUT;
    }
    interface schedulePUTRequest {
        scheduleUtc?: moment.Moment;
        callbackUrl?: string;
    }
}
export declare namespace Lobby {
    interface LobbyInfo {
        id: string | null;
        name: string | null;
        ownerSessionId: string | null;
        ownerAccountId: string | null;
        currentSessions: number | null;
        maxSessions: number | null;
    }
    interface ConnectedSession {
        lobbyId: string | null;
        sessionId: string | null;
    }
    class LobbyClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        lobbiesPaginatedGET(req: lobbiesPaginatedGETRequest): Promise<PaginatedResults<LobbyInfo>>;
        private __lobbiesPaginatedGET;
        lobbiesGET(req: lobbiesGETRequest): Promise<LobbyInfo[]>;
        private __lobbiesGET;
        lobbyGET(req: lobbyGETRequest): Promise<LobbyInfo>;
        private __lobbyGET;
        lobbyPUT(req: lobbyPUTRequest): Promise<LobbyInfo>;
        private __lobbyPUT;
        lobbyPOST(req: lobbyPOSTRequest): Promise<LobbyInfo>;
        private __lobbyPOST;
        lobbyDELETE(req: lobbyDELETERequest): Promise<boolean>;
        private __lobbyDELETE;
        sessionsGET(req: sessionsGETRequest): Promise<ConnectedSession[]>;
        private __sessionsGET;
        sessionGET(req: sessionGETRequest): Promise<ConnectedSession>;
        private __sessionGET;
        sessionPUT(req: sessionPUTRequest): Promise<ConnectedSession>;
        private __sessionPUT;
        sessionDELETE(req: sessionDELETERequest): Promise<boolean>;
        private __sessionDELETE;
    }
    interface lobbiesPaginatedGETRequest {
        start?: string;
        limit?: number;
    }
    interface lobbiesGETRequest {
    }
    interface lobbyGETRequest {
        id?: string;
    }
    interface lobbyPUTRequest {
        name?: string;
        maxSessions?: number;
    }
    interface lobbyPOSTRequest {
        id?: string;
        name?: string;
        maxSessions?: number;
    }
    interface lobbyDELETERequest {
        id?: string;
    }
    interface sessionsGETRequest {
        id?: string;
    }
    interface sessionGETRequest {
        lobbyId?: string;
        sessionId?: string;
    }
    interface sessionPUTRequest {
        lobbyId?: string;
        sessionId?: string;
    }
    interface sessionDELETERequest {
        lobbyId?: string;
        sessionId?: string;
    }
}
export declare namespace TemporarySession {
    interface TempSession {
        id: string | null;
        expiry: number | null;
        start: number | null;
        billedMinutes: number | null;
    }
    interface TempSessionWithSecrets {
        id: string | null;
        expiry: number | null;
        start: number | null;
        billedMinutes: number | null;
        apiKey: string | null;
        secretKey: string | null;
    }
    interface PaginatedTempSessions {
        next: string | null;
        moreResults: boolean;
        results: TempSession[];
    }
    class TemporarySessionClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        sessionGET(req: sessionGETRequest): Promise<TempSession>;
        private __sessionGET;
        sessionPUT(req: sessionPUTRequest): Promise<TempSessionWithSecrets>;
        private __sessionPUT;
        sessionPOST(req: sessionPOSTRequest): Promise<TempSession>;
        private __sessionPOST;
        sessionDELETE(req: sessionDELETERequest): Promise<boolean>;
        private __sessionDELETE;
    }
    interface sessionGETRequest {
        id?: string;
    }
    interface sessionPUTRequest {
    }
    interface sessionPOSTRequest {
        id: string;
    }
    interface sessionDELETERequest {
        id: string;
    }
    class TemporarySessionAdminClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        sessionsGET(req: sessionsGETRequest): Promise<PaginatedTempSessions>;
        private __sessionsGET;
    }
    interface sessionsGETRequest {
        start?: string;
        limit?: number;
    }
}
export declare namespace UserSession {
    interface UserAccountDigitalLicense {
        accountId: string | null;
        projectId: string | null;
        productId: string | null;
        isRevoked: boolean | null;
        dateExpiresUtc: moment.Moment | null;
    }
    interface UserAccountListedDigitalLicense {
        accountId: string | null;
        projectId: string | null;
        projectName: string | null;
        productId: string | null;
        productName: string | null;
        dateExpiresUtc: moment.Moment | null;
    }
    interface UserProfile {
        id: string | null;
        displayName: string | null;
        realName: string | null;
        handle: string | null;
        locationText: string | null;
        locationCity: string | null;
        locationState: string | null;
        locationCountry: string | null;
        descriptionUnsafeMarkdown: string | null;
        descriptionHtml: string | null;
        avatarUrl: string | null;
        allowDiscoveryByEmailAddress: boolean | null;
        allowPublicVisibility: boolean | null;
        relationship: string | null;
        passwordResetPending: boolean | null;
        emailVerificationPending: boolean | null;
        canSendVerificationEmail: boolean | null;
    }
    interface LocationGeocodeResult {
        isAvailable: boolean | null;
        geocodeAccuracy: string | null;
        latitude: number | null;
        longitude: number | null;
    }
    interface OAuthFlowSessionSessionToken {
        sessionToken: string | null;
    }
    interface OAuthProvider {
        id: string | null;
        providerFriendlyName: string | null;
    }
    interface OAuthFlowSessionStatus {
        status: string | null;
        providerFriendlyName: string | null;
        systemError: HiveMPSystemError | null;
    }
    interface OAuthFlowStartingUrl {
        startingUrl: string | null;
    }
    interface ProjectRoleAccessEntry {
        id: string | null;
        type: string | null;
        sourceId: string | null;
        sourceName: string | null;
        targetProjectId: string | null;
        targetProjectName: string | null;
        role: string | null;
        delegating: boolean | null;
    }
    interface ProjectRoleAccessEntryGrant {
        sourceId: string | null;
        targetProjectId: string | null;
        role: string | null;
        delegating: boolean | null;
    }
    interface UserProfileUpdate {
        displayName: string | null;
        realName: string | null;
        locationCity: string | null;
        locationState: string | null;
        locationCountry: string | null;
        descriptionUnsafeMarkdown: string | null;
        allowDiscoveryByEmailAddress: boolean | null;
        allowPublicVisibility: boolean | null;
    }
    interface UserSession {
        id: string | null;
        accountId: string | null;
        projectId: string | null;
        profile: UserProfile | null;
        expiry: number | null;
        start: number | null;
        billedMinutes: number | null;
        metered: boolean | null;
    }
    interface UserSessionWithSecrets {
        id: string | null;
        accountId: string | null;
        projectId: string | null;
        profile: UserProfile | null;
        expiry: number | null;
        start: number | null;
        billedMinutes: number | null;
        apiKey: string | null;
        secretKey: string | null;
        metered: boolean | null;
    }
    interface AuthenticationSwitchRequest {
        projectId: string | null;
    }
    interface AuthenticationResponse {
        authenticatedSession: UserSessionWithSecrets | null;
        promptForEmailAddress: boolean | null;
        promptForPassword: boolean | null;
        promptForMarketingPreferenceOptIn: boolean | null;
        promptForTwoFactor: boolean | null;
        passwordResetEmailSent: boolean | null;
        intent: string | null;
        promptForProject: boolean | null;
        availableProjects: UserAvailableProject[] | null;
    }
    interface UserAvailableProject {
        projectId: string | null;
        projectName: string | null;
        projectPublicAvatarUrl: string | null;
    }
    interface AuthenticationRequest {
        tokens: AuthenticationRequestTokens | null;
        emailAddress: string | null;
        passwordHash: string | null;
        marketingPreferenceOptIn: boolean | null;
        twoFactor: AuthenticationRequestTwoFactor | null;
        requestedRole: string | null;
        metered: boolean | null;
        promptForProject: boolean | null;
        projectId: string | null;
    }
    interface AuthenticationRequestTokens {
        steamTokens: AuthenticationRequestSteamToken[] | null;
        itchIoTokens: AuthenticationRequestItchIoToken[] | null;
        discordTokens: AuthenticationRequestDiscordToken[] | null;
        deviceTestTokens: AuthenticationRequestDeviceTestToken[] | null;
        oAuthTokens: AuthenticationRequestOAuthToken[] | null;
        existingSessionTokens: AuthenticationRequestExistingSessionToken[] | null;
    }
    interface AuthenticationRequestTwoFactor {
        deviceIdentifier: string | null;
        deviceIdentifierFriendlyName: string | null;
        twoFactorCode: string | null;
        trustThisDevice: boolean | null;
    }
    interface AuthenticationRequestSteamToken {
        userTicket: string | null;
    }
    interface AuthenticationRequestItchIoToken {
        apiKey: string | null;
    }
    interface AuthenticationRequestDiscordToken {
        authorizationCode: string | null;
    }
    interface AuthenticationRequestDeviceTestToken {
        deviceIdentifier: string | null;
    }
    interface AuthenticationRequestOAuthToken {
        sessionToken: string | null;
    }
    interface AuthenticationRequestExistingSessionToken {
        apiKey: string | null;
    }
    class DigitalLicenseClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        digitalLicenseGrantPUT(req: digitalLicenseGrantPUTRequest): Promise<UserAccountDigitalLicense>;
        private __digitalLicenseGrantPUT;
        digitalLicenseRevokeDELETE(req: digitalLicenseRevokeDELETERequest): Promise<UserAccountDigitalLicense>;
        private __digitalLicenseRevokeDELETE;
        digitalLicenseValidateGET(req: digitalLicenseValidateGETRequest): Promise<UserAccountDigitalLicense>;
        private __digitalLicenseValidateGET;
        digitalLicensesGET(req: digitalLicensesGETRequest): Promise<PaginatedResults<UserAccountListedDigitalLicense>>;
        private __digitalLicensesGET;
    }
    interface digitalLicenseGrantPUTRequest {
        accountId: string;
        productId: string;
    }
    interface digitalLicenseRevokeDELETERequest {
        accountId: string;
        productId: string;
    }
    interface digitalLicenseValidateGETRequest {
        productId: string;
    }
    interface digitalLicensesGETRequest {
        start?: string;
        limit?: number;
    }
    class FriendClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        friendsGET(req: friendsGETRequest): Promise<PaginatedResults<UserProfile>>;
        private __friendsGET;
        friendRequestsGET(req: friendRequestsGETRequest): Promise<PaginatedResults<UserProfile>>;
        private __friendRequestsGET;
        friendRequestsSentGET(req: friendRequestsSentGETRequest): Promise<PaginatedResults<UserProfile>>;
        private __friendRequestsSentGET;
        friendRequestsSendPUT(req: friendRequestsSendPUTRequest): Promise<boolean>;
        private __friendRequestsSendPUT;
        friendRequestsRescindDELETE(req: friendRequestsRescindDELETERequest): Promise<boolean>;
        private __friendRequestsRescindDELETE;
        friendRequestsAcceptPUT(req: friendRequestsAcceptPUTRequest): Promise<boolean>;
        private __friendRequestsAcceptPUT;
        friendRequestsRejectDELETE(req: friendRequestsRejectDELETERequest): Promise<boolean>;
        private __friendRequestsRejectDELETE;
    }
    interface friendsGETRequest {
        id: string;
        start?: string;
        limit?: number;
    }
    interface friendRequestsGETRequest {
        id: string;
        start?: string;
        limit?: number;
    }
    interface friendRequestsSentGETRequest {
        id: string;
        start?: string;
        limit?: number;
    }
    interface friendRequestsSendPUTRequest {
        id: string;
        sendQuery: string;
    }
    interface friendRequestsRescindDELETERequest {
        id: string;
        targetId: string;
    }
    interface friendRequestsAcceptPUTRequest {
        id: string;
        targetId: string;
    }
    interface friendRequestsRejectDELETERequest {
        id: string;
        targetId: string;
    }
    class LocationClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        locationCountryNamesGET(req: locationCountryNamesGETRequest): Promise<string[]>;
        private __locationCountryNamesGET;
        locationStateNamesGET(req: locationStateNamesGETRequest): Promise<string[]>;
        private __locationStateNamesGET;
        locationCityNamesGET(req: locationCityNamesGETRequest): Promise<string[]>;
        private __locationCityNamesGET;
        locationGeocodeGET(req: locationGeocodeGETRequest): Promise<LocationGeocodeResult>;
        private __locationGeocodeGET;
    }
    interface locationCountryNamesGETRequest {
    }
    interface locationStateNamesGETRequest {
        country: string;
    }
    interface locationCityNamesGETRequest {
        country: string;
        state: string;
    }
    interface locationGeocodeGETRequest {
        country: string;
        state?: string;
        city?: string;
    }
    class OAuthClientClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        flowSessionPUT(req: flowSessionPUTRequest): Promise<OAuthFlowSessionSessionToken>;
        private __flowSessionPUT;
        providersGET(req: providersGETRequest): Promise<PaginatedResults<OAuthProvider>>;
        private __providersGET;
        flowSessionStatusGET(req: flowSessionStatusGETRequest): Promise<OAuthFlowSessionStatus>;
        private __flowSessionStatusGET;
        startingUrlGET(req: startingUrlGETRequest): Promise<OAuthFlowStartingUrl>;
        private __startingUrlGET;
        receivePlatformGET(req: receivePlatformGETRequest): Promise<void>;
        private __receivePlatformGET;
    }
    interface flowSessionPUTRequest {
        destinationUrl: string;
    }
    interface providersGETRequest {
    }
    interface flowSessionStatusGETRequest {
        sessionToken: string;
    }
    interface startingUrlGETRequest {
        provider: string;
        sessionToken: string;
    }
    interface receivePlatformGETRequest {
        platform: string;
    }
    class RoleAccessClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        roleAccessGET(req: roleAccessGETRequest): Promise<ProjectRoleAccessEntry[]>;
        private __roleAccessGET;
        roleAccessPUT(req: roleAccessPUTRequest): Promise<ProjectRoleAccessEntry>;
        private __roleAccessPUT;
        roleAccessDELETE(req: roleAccessDELETERequest): Promise<ProjectRoleAccessEntry>;
        private __roleAccessDELETE;
    }
    interface roleAccessGETRequest {
        id: string;
    }
    interface roleAccessPUTRequest {
        grant?: ProjectRoleAccessEntryGrant;
    }
    interface roleAccessDELETERequest {
        sourceId?: string;
        id?: string;
    }
    class UserAccountClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        profileAvatarPUT(req: profileAvatarPUTRequest): Promise<UserProfile>;
        private __profileAvatarPUT;
        profileHandlePUT(req: profileHandlePUTRequest): Promise<UserProfile>;
        private __profileHandlePUT;
        accountPasswordChangeWithSessionPUT(req: accountPasswordChangeWithSessionPUTRequest): Promise<UserProfile>;
        private __accountPasswordChangeWithSessionPUT;
        accountPasswordChangeWithSessionCompletePUT(req: accountPasswordChangeWithSessionCompletePUTRequest): Promise<UserProfile>;
        private __accountPasswordChangeWithSessionCompletePUT;
        accountPasswordChangeByEmailAddressPUT(req: accountPasswordChangeByEmailAddressPUTRequest): Promise<boolean>;
        private __accountPasswordChangeByEmailAddressPUT;
        accountPasswordChangeByEmailAddressCompletePUT(req: accountPasswordChangeByEmailAddressCompletePUTRequest): Promise<boolean>;
        private __accountPasswordChangeByEmailAddressCompletePUT;
        profileDiscoverGET(req: profileDiscoverGETRequest): Promise<UserProfile>;
        private __profileDiscoverGET;
        profileGET(req: profileGETRequest): Promise<UserProfile>;
        private __profileGET;
        profilePOST(req: profilePOSTRequest): Promise<UserProfile>;
        private __profilePOST;
    }
    interface profileAvatarPUTRequest {
        id: string;
        content: Buffer | ArrayBuffer;
    }
    interface profileHandlePUTRequest {
        id: string;
        handle?: string;
    }
    interface accountPasswordChangeWithSessionPUTRequest {
        id: string;
    }
    interface accountPasswordChangeWithSessionCompletePUTRequest {
        id: string;
        resetCode?: string;
        passwordHash?: string;
    }
    interface accountPasswordChangeByEmailAddressPUTRequest {
        emailAddress: string;
    }
    interface accountPasswordChangeByEmailAddressCompletePUTRequest {
        emailAddress: string;
        resetCode?: string;
        passwordHash?: string;
    }
    interface profileDiscoverGETRequest {
        query: string;
    }
    interface profileGETRequest {
        id: string;
    }
    interface profilePOSTRequest {
        id: string;
        profileUpdate?: UserProfileUpdate;
    }
    class UserSessionClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        sessionGET(req: sessionGETRequest): Promise<UserSession>;
        private __sessionGET;
        sessionPUT(req: sessionPUTRequest): Promise<UserSessionWithSecrets>;
        private __sessionPUT;
        sessionPOST(req: sessionPOSTRequest): Promise<UserSession>;
        private __sessionPOST;
        sessionDELETE(req: sessionDELETERequest): Promise<boolean>;
        private __sessionDELETE;
        authenticateSwitchPUT(req: authenticateSwitchPUTRequest): Promise<AuthenticationResponse>;
        private __authenticateSwitchPUT;
        authenticatePUT(req: authenticatePUTRequest): Promise<AuthenticationResponse>;
        private __authenticatePUT;
    }
    interface sessionGETRequest {
        id?: string;
    }
    interface sessionPUTRequest {
        authenticationProvider: string;
        credentials: string;
    }
    interface sessionPOSTRequest {
        id?: string;
    }
    interface sessionDELETERequest {
        id?: string;
    }
    interface authenticateSwitchPUTRequest {
        authenticationSwitch?: AuthenticationSwitchRequest;
    }
    interface authenticatePUTRequest {
        authentication?: AuthenticationRequest;
    }
}
export declare namespace Attribute {
    interface AttributeKey {
        key: string | null;
        ownerId: string | null;
    }
    interface AttributeData {
        key: string | null;
        ownerId: string | null;
        value: string | null;
    }
    class AttributeClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        attributesGET(req: attributesGETRequest): Promise<AttributeKey[]>;
        private __attributesGET;
        attributeGET(req: attributeGETRequest): Promise<AttributeData>;
        private __attributeGET;
        attributePUT(req: attributePUTRequest): Promise<boolean>;
        private __attributePUT;
        attributeDELETE(req: attributeDELETERequest): Promise<boolean>;
        private __attributeDELETE;
    }
    interface attributesGETRequest {
        id?: string;
    }
    interface attributeGETRequest {
        id?: string;
        key?: string;
        ownerId?: string;
    }
    interface attributePUTRequest {
        id?: string;
        key?: string;
        value?: string;
        useProjectAsOwner?: boolean;
    }
    interface attributeDELETERequest {
        id?: string;
        key?: string;
        ownerId?: string;
    }
}
export declare namespace ClientConnect {
    interface ClientConnectAsset {
        sha1: string | null;
        url: string | null;
    }
    class FilesClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        filesGET(req: filesGETRequest): Promise<{
            [key: string]: ClientConnectAsset;
        }>;
        private __filesGET;
        serveGET(req: serveGETRequest): Promise<void>;
        private __serveGET;
    }
    interface filesGETRequest {
    }
    interface serveGETRequest {
        path?: string;
    }
    class ServiceClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        serviceEnabledGET(req: serviceEnabledGETRequest): Promise<boolean>;
        private __serviceEnabledGET;
        serviceTestPUT(req: serviceTestPUTRequest): Promise<boolean>;
        private __serviceTestPUT;
    }
    interface serviceEnabledGETRequest {
    }
    interface serviceTestPUTRequest {
        testName?: string;
    }
}
export declare namespace UGCCache {
    interface UGCCacheItem {
        Id: string | null;
        LookupKey: string | null;
        Owner: string | null;
    }
    class UGCCacheClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        itemPUT(req: itemPUTRequest): Promise<UGCCacheItem>;
        private __itemPUT;
        contentGET(req: contentGETRequest): Promise<void>;
        private __contentGET;
    }
    interface itemPUTRequest {
        lookupKey?: string;
        content: Buffer | ArrayBuffer;
    }
    interface contentGETRequest {
        lookupKey?: string;
    }
}
export declare namespace NATPunchthrough {
    interface NATNegotation {
        host: string | null;
        port: number | null;
        message: Buffer | ArrayBuffer | null;
    }
    interface NATEndpoint {
        host: string | null;
        port: number | null;
    }
    class PunchthroughClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        punchthroughGET(req: punchthroughGETRequest): Promise<boolean>;
        private __punchthroughGET;
        punchthroughPUT(req: punchthroughPUTRequest): Promise<NATNegotation>;
        private __punchthroughPUT;
        endpointsGET(req: endpointsGETRequest): Promise<NATEndpoint[]>;
        private __endpointsGET;
    }
    interface punchthroughGETRequest {
        session?: string;
    }
    interface punchthroughPUTRequest {
        session?: string;
    }
    interface endpointsGETRequest {
        session?: string;
    }
}
export declare namespace Search {
    interface InternalSearchResult {
        objectId: string | null;
        title: string | null;
    }
    class ClusterClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
    }
    class SearchClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        searchGET(req: searchGETRequest): Promise<InternalSearchResult[]>;
        private __searchGET;
        indexPUT(req: indexPUTRequest): Promise<boolean>;
        private __indexPUT;
        indexDELETE(req: indexDELETERequest): Promise<boolean>;
        private __indexDELETE;
    }
    interface searchGETRequest {
        type?: string;
        input?: string;
    }
    interface indexPUTRequest {
        type?: string;
        id?: string;
        title?: string;
        text?: string;
    }
    interface indexDELETERequest {
        type?: string;
        id?: string;
    }
}
export declare namespace NetcodeIO {
    interface PublicNetcodeServer {
        id: string | null;
        name: string | null;
    }
    interface ConnectTokenResult {
        connectToken: Buffer | ArrayBuffer | null;
    }
    interface NetcodeServer {
        id: string | null;
        name: string | null;
        serverPrivateKey: Buffer | ArrayBuffer | null;
        serverProtocolIdHexadecimal: string | null;
        serverIpAddress: string | null;
        serverPort: number | null;
        tokenExpirySeconds: number | null;
        serverTimeoutSeconds: number | null;
        userdataMode: string | null;
    }
    class NetcodePublicClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        publicServersGET(req: publicServersGETRequest): Promise<PaginatedResults<PublicNetcodeServer>>;
        private __publicServersGET;
        publicServerGET(req: publicServerGETRequest): Promise<PublicNetcodeServer>;
        private __publicServerGET;
        publicServerAuthPUT(req: publicServerAuthPUTRequest): Promise<ConnectTokenResult>;
        private __publicServerAuthPUT;
    }
    interface publicServersGETRequest {
        start?: string;
        limit?: number;
    }
    interface publicServerGETRequest {
        id: string;
    }
    interface publicServerAuthPUTRequest {
        id: string;
    }
    class NetcodeServerClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        serversGET(req: serversGETRequest): Promise<PaginatedResults<NetcodeServer>>;
        private __serversGET;
        serverGET(req: serverGETRequest): Promise<NetcodeServer>;
        private __serverGET;
        serverPUT(req: serverPUTRequest): Promise<NetcodeServer>;
        private __serverPUT;
        serverPOST(req: serverPOSTRequest): Promise<NetcodeServer>;
        private __serverPOST;
        serverDELETE(req: serverDELETERequest): Promise<NetcodeServer>;
        private __serverDELETE;
    }
    interface serversGETRequest {
        start?: string;
        limit?: number;
    }
    interface serverGETRequest {
        id: string;
    }
    interface serverPUTRequest {
        name: string;
        serverPrivateKey: Buffer | ArrayBuffer;
        serverProtocolIdHexadecimal: string;
        serverIpAddress: string;
        serverPort: number;
        tokenExpirySeconds: number;
        serverTimeoutSeconds: number;
        userdataMode: string;
    }
    interface serverPOSTRequest {
        id: string;
        name: string;
        serverPrivateKey: Buffer | ArrayBuffer;
        serverProtocolIdHexadecimal: string;
        serverIpAddress: string;
        serverPort: number;
        tokenExpirySeconds: number;
        serverTimeoutSeconds: number;
        userdataMode: string;
    }
    interface serverDELETERequest {
        id: string;
    }
}
export declare namespace Presence {
    interface PresenceInitialMessage {
        friends: FriendCurrentPresence[] | null;
    }
    interface FriendCurrentPresence {
        friendAccountId: string | null;
        online: boolean | null;
    }
    interface PresenceUpdateMessage {
        friendAccountId: string | null;
        online: boolean | null;
    }
    interface PresenceStatus {
        id: string | null;
        online: boolean | null;
    }
    class PresenceClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        presenceConnectGET(req: presenceConnectGETRequest): Promise<void>;
        private __presenceConnectGET;
        presenceUserGET(req: presenceUserGETRequest): Promise<PresenceStatus>;
        private __presenceUserGET;
    }
    interface presenceConnectGETRequest {
    }
    interface presenceUserGETRequest {
        id: string;
    }
}
export declare namespace PointOfSale {
    interface PaginatedPointOfSaleEvents {
        next: string | null;
        moreResults: boolean;
        results: PointOfSaleEvent[];
    }
    interface PointOfSaleEvent {
        id: string | null;
        name: string | null;
        visible: boolean | null;
        eventStartUtc: moment.Moment | null;
        eventEndUtc: moment.Moment | null;
        productIds: string[] | null;
    }
    interface PointOfSaleEventSearchResult {
        id: string | null;
        name: string | null;
    }
    interface PaginatedLicenseKeyPools {
        next: string | null;
        moreResults: boolean;
        results: LicenseKeyPool[];
    }
    interface LicenseKeyPool {
        id: string | null;
        name: string | null;
        visible: boolean | null;
        description: string | null;
        availableKeys: number | null;
        reservedKeys: number | null;
        issuedKeys: number | null;
        activatedKeys: number | null;
    }
    interface LicenseKeyPoolSearchResult {
        id: string | null;
        name: string | null;
    }
    interface PoolInsertResults {
        newKeys: number | null;
        results: {
            [key: string]: string;
        } | null;
    }
    interface ReservedKey {
        licenseKeyPoolId: string | null;
        licenseKey: string | null;
        reservedForEmail: string | null;
        reservedOnDate: number | null;
    }
    interface IssuedKey {
        licenseKeyPoolId: string | null;
        licenseKey: string | null;
        issuedToEmail: string | null;
        issuedOnDate: number | null;
    }
    interface LicenseKey {
        key: string | null;
        licensePoolId: string | null;
        reservedForEmail: string | null;
        dateReservedUtc: moment.Moment | null;
        issuedToEmail: string | null;
        dateIssuedUtc: moment.Moment | null;
        notes: string | null;
        dateActivatedUtc: moment.Moment | null;
    }
    interface ProductPointOfSale {
        productId: string | null;
        enabled: boolean | null;
        currencyCode: string | null;
        currencyUnits: number | null;
        licenseKeyPoolId: string | null;
    }
    class EventClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        eventsGET(req: eventsGETRequest): Promise<PaginatedPointOfSaleEvents>;
        private __eventsGET;
        eventsSearchGET(req: eventsSearchGETRequest): Promise<PointOfSaleEventSearchResult[]>;
        private __eventsSearchGET;
        eventGET(req: eventGETRequest): Promise<PointOfSaleEvent>;
        private __eventGET;
        eventPUT(req: eventPUTRequest): Promise<PointOfSaleEvent>;
        private __eventPUT;
        eventPOST(req: eventPOSTRequest): Promise<PointOfSaleEvent>;
        private __eventPOST;
    }
    interface eventsGETRequest {
        start?: string;
        limit?: number;
        showHidden?: boolean;
    }
    interface eventsSearchGETRequest {
        text?: string;
    }
    interface eventGETRequest {
        id?: string;
    }
    interface eventPUTRequest {
        name?: string;
        visible?: boolean;
        eventStartUtc?: moment.Moment;
        eventEndUtc?: moment.Moment;
        productIds?: string[];
    }
    interface eventPOSTRequest {
        id?: string;
        name?: string;
        visible?: boolean;
        eventStartUtc?: moment.Moment;
        eventEndUtc?: moment.Moment;
        productIds?: string[];
    }
    class LicenseKeyClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        poolsGET(req: poolsGETRequest): Promise<PaginatedLicenseKeyPools>;
        private __poolsGET;
        poolsSearchGET(req: poolsSearchGETRequest): Promise<LicenseKeyPoolSearchResult[]>;
        private __poolsSearchGET;
        poolGET(req: poolGETRequest): Promise<LicenseKeyPool>;
        private __poolGET;
        poolPUT(req: poolPUTRequest): Promise<LicenseKeyPool>;
        private __poolPUT;
        poolPOST(req: poolPOSTRequest): Promise<LicenseKeyPool>;
        private __poolPOST;
        keysPUT(req: keysPUTRequest): Promise<PoolInsertResults>;
        private __keysPUT;
        keysReservePUT(req: keysReservePUTRequest): Promise<ReservedKey>;
        private __keysReservePUT;
        keysIssuePUT(req: keysIssuePUTRequest): Promise<IssuedKey>;
        private __keysIssuePUT;
        keysByReservedEmailGET(req: keysByReservedEmailGETRequest): Promise<LicenseKey[]>;
        private __keysByReservedEmailGET;
        keysByIssuedEmailGET(req: keysByIssuedEmailGETRequest): Promise<LicenseKey[]>;
        private __keysByIssuedEmailGET;
    }
    interface poolsGETRequest {
        start?: string;
        limit?: number;
        showHidden?: boolean;
    }
    interface poolsSearchGETRequest {
        text?: string;
    }
    interface poolGETRequest {
        id?: string;
    }
    interface poolPUTRequest {
        name?: string;
        description?: string;
        visible?: boolean;
    }
    interface poolPOSTRequest {
        id?: string;
        name?: string;
        description?: string;
        visible?: boolean;
    }
    interface keysPUTRequest {
        id?: string;
        keys?: string[];
    }
    interface keysReservePUTRequest {
        poolId?: string;
        eventId?: string;
        userEmail?: string;
    }
    interface keysIssuePUTRequest {
        poolId?: string;
        eventId?: string;
        key?: string;
        userEmail?: string;
        notes?: string;
    }
    interface keysByReservedEmailGETRequest {
        poolId?: string;
        email?: string;
    }
    interface keysByIssuedEmailGETRequest {
        poolId?: string;
        email?: string;
    }
    class ProductClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        productGET(req: productGETRequest): Promise<ProductPointOfSale>;
        private __productGET;
        productPOST(req: productPOSTRequest): Promise<ProductPointOfSale>;
        private __productPOST;
    }
    interface productGETRequest {
        productId?: string;
    }
    interface productPOSTRequest {
        productId?: string;
        enabled?: boolean;
        currencyCode?: string;
        currencyUnits?: number;
        licenseKeyPoolId?: string;
    }
}
export declare namespace Billing {
    interface BillingAccountUserAccess {
        accountId: string | null;
        adminUsername: string | null;
        userAccountId: string | null;
    }
    interface PaginatedBillingAccountUserAccess {
        next: string | null;
        moreResults: boolean;
        results: BillingAccountUserAccess[];
    }
    interface BillingAccount {
        name: string | null;
        description: string | null;
        billingAddress: BillingAccountAddress | null;
        emailAddress: string | null;
    }
    interface BillingAccountAddress {
        name: string | null;
        cityOrTown: string | null;
        line1: string | null;
        line2: string | null;
        phone: string | null;
        state: string | null;
        postalCode: string | null;
        country: string | null;
    }
    interface BillingAccountState {
        id: string | null;
        archived: boolean | null;
        hasSourcePaymentConfigured: boolean | null;
        hasUnpaidInvoices: boolean | null;
        upcomingInvoiceStatus: string | null;
        name: string | null;
        description: string | null;
        billingAddress: BillingAccountAddress | null;
        emailAddress: string | null;
    }
    interface PaginatedBillingAccounts {
        next: string | null;
        moreResults: boolean;
        results: BillingAccountState[];
    }
    interface AggregationStatus {
        lastAggregatedUtc: moment.Moment | null;
        aggregatedToUtc: moment.Moment | null;
        estimatedUsdCents: number | null;
        versionGuid: string | null;
        lineItems: AggregationStatusLineItem[] | null;
        hasAggregated: boolean | null;
    }
    interface AggregationStatusLineItem {
        type: string | null;
        englishDescriptionFormat: string | null;
        units: number | null;
        estimatedUsdCents: number | null;
    }
    interface AggregationLineItemModifier {
        type: string | null;
        unitsIncrement: number | null;
    }
    interface BillingAccountDiscount {
        activeDiscount: string | null;
    }
    interface PaginatedBillingAccountInvoices {
        next: string | null;
        moreResults: boolean;
        results: BillingAccountInvoice[];
    }
    interface BillingAccountInvoice {
        accountId: string | null;
        invoiceId: string | null;
        dateCreatedUtc: moment.Moment | null;
        status: string | null;
        detailsAttached: boolean | null;
        amountDueUsdCents: number | null;
        attempted: boolean | null;
        attemptCount: number | null;
        dueDateUtc: moment.Moment | null;
        forgiven: boolean | null;
        upcoming: boolean | null;
        invoiceNumber: string | null;
        periodStartUtc: moment.Moment | null;
        periodEndUtc: moment.Moment | null;
        startingBalanceUsdCents: number | null;
        endingBalanceUsdCents: number | null;
        subtotalUsdCents: number | null;
        taxUsdCents: number | null;
        taxPercent: number | null;
        totalUsd: number | null;
        lineItems: BillingAccountInvoiceLineItem[] | null;
    }
    interface BillingAccountInvoiceLineItem {
        amountUsdCents: number | null;
        periodStartUtc: moment.Moment | null;
        periodEndUtc: moment.Moment | null;
        description: string | null;
        stripeId: string | null;
    }
    interface PaginatedBillingAccountSubscriptions {
        next: string | null;
        moreResults: boolean;
        results: BillingAccountSubscription[];
    }
    interface BillingAccountSubscription {
        accountId: string | null;
        subscriptionId: string | null;
        planId: string | null;
        expiryOrNextRenewal: number | null;
        autoRenew: boolean | null;
    }
    interface BillingAccountSubscriptionSlot {
        accountId: string | null;
        subscriptionId: string | null;
        slotNum: number | null;
        assignedProjectId: string | null;
    }
    interface PaginatedPlans {
        next: string | null;
        moreResults: boolean;
        results: Plan[];
    }
    interface Plan {
        id: string | null;
        name: string | null;
        monthlyChargeUsdCents: string | null;
    }
    interface BillingAccountProject {
        accountId: string | null;
        projectId: string | null;
        projectName: string | null;
    }
    interface PaginatedBillingAccountProjects {
        next: string | null;
        moreResults: boolean;
        results: BillingAccountProject[];
    }
    interface StripePublicInfo {
        publicKey: string | null;
    }
    class AccessClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        accountUserAccessPUT(req: accountUserAccessPUTRequest): Promise<BillingAccountUserAccess>;
        private __accountUserAccessPUT;
        accountUserAccessDELETE(req: accountUserAccessDELETERequest): Promise<BillingAccountUserAccess>;
        private __accountUserAccessDELETE;
        accountUsersAccessGET(req: accountUsersAccessGETRequest): Promise<PaginatedBillingAccountUserAccess>;
        private __accountUsersAccessGET;
    }
    interface accountUserAccessPUTRequest {
        accountId: string;
        adminUsername?: string;
        userAccountId?: string;
    }
    interface accountUserAccessDELETERequest {
        accountId: string;
        adminUsername?: string;
        userAccountId?: string;
    }
    interface accountUsersAccessGETRequest {
        accountId: string;
    }
    class AccountClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        accountGET(req: accountGETRequest): Promise<BillingAccountState>;
        private __accountGET;
        accountPUT(req: accountPUTRequest): Promise<BillingAccountState>;
        private __accountPUT;
        accountPOST(req: accountPOSTRequest): Promise<BillingAccountState>;
        private __accountPOST;
        accountPaymentSingularPUT(req: accountPaymentSingularPUTRequest): Promise<BillingAccountState>;
        private __accountPaymentSingularPUT;
        accountsGET(req: accountsGETRequest): Promise<PaginatedBillingAccounts>;
        private __accountsGET;
        accountChargePUT(req: accountChargePUTRequest): Promise<boolean>;
        private __accountChargePUT;
        accountSyncPUT(req: accountSyncPUTRequest): Promise<boolean>;
        private __accountSyncPUT;
    }
    interface accountGETRequest {
        id: string;
    }
    interface accountPUTRequest {
        account: BillingAccount;
    }
    interface accountPOSTRequest {
        id: string;
        account: BillingAccount;
        archived: boolean;
    }
    interface accountPaymentSingularPUTRequest {
        id: string;
        token: string;
    }
    interface accountsGETRequest {
        start?: string;
        limit?: number;
    }
    interface accountChargePUTRequest {
        id: string;
    }
    interface accountSyncPUTRequest {
        id: string;
    }
    class AggregationClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        aggregationInfoGET(req: aggregationInfoGETRequest): Promise<AggregationStatus>;
        private __aggregationInfoGET;
        aggregationQueuePUT(req: aggregationQueuePUTRequest): Promise<boolean>;
        private __aggregationQueuePUT;
    }
    interface aggregationInfoGETRequest {
    }
    interface aggregationQueuePUTRequest {
    }
    class DiscountClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        accountDiscountGET(req: accountDiscountGETRequest): Promise<BillingAccountDiscount>;
        private __accountDiscountGET;
    }
    interface accountDiscountGETRequest {
        accountId: string;
    }
    class InvoiceClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        accountInvoicesGET(req: accountInvoicesGETRequest): Promise<PaginatedBillingAccountInvoices>;
        private __accountInvoicesGET;
        accountInvoiceGET(req: accountInvoiceGETRequest): Promise<BillingAccountInvoice>;
        private __accountInvoiceGET;
    }
    interface accountInvoicesGETRequest {
        accountId: string;
        start?: string;
        limit?: number;
    }
    interface accountInvoiceGETRequest {
        accountId: string;
        invoiceId: string;
    }
    class PlanClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
    }
    class ProjectClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        accountProjectPUT(req: accountProjectPUTRequest): Promise<BillingAccountProject>;
        private __accountProjectPUT;
        accountProjectsGET(req: accountProjectsGETRequest): Promise<PaginatedBillingAccountProjects>;
        private __accountProjectsGET;
    }
    interface accountProjectPUTRequest {
        accountId: string;
        projectId: string;
    }
    interface accountProjectsGETRequest {
        accountId: string;
        start?: string;
        limit?: number;
    }
    class StripeClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        stripeWebhookPOST(req: stripeWebhookPOSTRequest): Promise<void>;
        private __stripeWebhookPOST;
        stripePublicKeyGET(req: stripePublicKeyGETRequest): Promise<StripePublicInfo>;
        private __stripePublicKeyGET;
    }
    interface stripeWebhookPOSTRequest {
    }
    interface stripePublicKeyGETRequest {
    }
}
export declare namespace IntegrationConfiguration {
    interface IntegrationCredential {
        id: string | null;
        type: string | null;
        name: string | null;
        description: string | null;
        enabled: boolean | null;
        visible: boolean | null;
        status: string | null;
        errorMessage: string | null;
        authenticationFields: {
            [key: string]: SettableStringValue;
        } | null;
        twoFactorFields: {
            [key: string]: SettableStringValue;
        } | null;
        captchaFields: {
            [key: string]: SettableStringValue;
        } | null;
        captchaImageUrls: {
            [key: string]: string;
        } | null;
        stateJson: string | null;
    }
    interface SettableStringValue {
        isValuePresent: boolean | null;
        shouldUpdateValue: boolean | null;
        value: string | null;
    }
    interface IntegrationCredentialType {
        type: string | null;
        name: string | null;
        authenticationType: string | null;
        authenticationFieldDefinitions: {
            [key: string]: AuthenticationFieldDefinition;
        } | null;
        twoFactorFieldDefinitions: {
            [key: string]: AuthenticationFieldDefinition;
        } | null;
    }
    interface AuthenticationFieldDefinition {
        label: string | null;
        helpText: string | null;
        isPassword: boolean | null;
        isTextArea: boolean | null;
    }
    interface SearchResult {
        id: string | null;
        name: string | null;
    }
    interface IntegrationCredentialBase {
        type: string | null;
        name: string | null;
        description: string | null;
        enabled: boolean | null;
        visible: boolean | null;
        status: string | null;
        errorMessage: string | null;
        authenticationFields: {
            [key: string]: SettableStringValue;
        } | null;
        twoFactorFields: {
            [key: string]: SettableStringValue;
        } | null;
        captchaFields: {
            [key: string]: SettableStringValue;
        } | null;
        captchaImageUrls: {
            [key: string]: string;
        } | null;
        stateJson: string | null;
    }
    interface IntegrationCredentialInternalStateUpdate {
        status: string | null;
        stateJson: string | null;
        captchaImageUrls: {
            [key: string]: string;
        } | null;
        errorMessage: string | null;
    }
    interface SteamIntegrationSummary {
        appId: string | null;
        partnerPortalUsername: string | null;
        connectionStatus: string | null;
        lastAuthError: string | null;
        lastRecordedWishlistDate: number | null;
        lastRecordedTrafficDate: number | null;
        lastRecordedSalesDate: number | null;
    }
    interface SteamGuardStatus {
        status: string | null;
    }
    interface SteamCredentials {
        encryptedAppId: string | null;
        encryptedPublisherKey: string | null;
        encryptedPublisherUsername: string | null;
        encryptedPublisherPassword: string | null;
        encryptedPartnerSteamGuardCookie: string | null;
        encryptedPartnerCurrentPoweredCookie: string | null;
        encryptedPartnerCurrentGamesCookie: string | null;
        encryptedPartnerCurrentGamesSessionCookie: string | null;
    }
    interface SteamSaleDataState {
        date: number | null;
        index: number | null;
    }
    interface PackageData {
        packageHash: string | null;
        packagesList: PackagesList | null;
    }
    interface PackagesList {
        packages: PackageRow[] | null;
    }
    interface PackageRow {
        appId: string | null;
        type: string | null;
        packageId: string | null;
        packageTitle: string | null;
        releaseDatePst: number | null;
        lastModifiedPst: number | null;
        subtype: string | null;
        status: string | null;
        basePriceUsd: number | null;
        pricing: PricingRow[] | null;
        discounts: DiscountRow[] | null;
        appsIncluded: AppIncludedRow[] | null;
        depotsIncluded: DepotIncludedRow[] | null;
    }
    interface PricingRow {
        currency: string | null;
        price: number | null;
    }
    interface DiscountRow {
        discountName: string | null;
        discountType: string | null;
        startDateUtc: moment.Moment | null;
        endDateUtc: moment.Moment | null;
        amountUsd: number | null;
        percentage: number | null;
    }
    interface AppIncludedRow {
        appId: string | null;
        appTitle: string | null;
        status: string | null;
    }
    interface DepotIncludedRow {
        depotId: string | null;
        depotTitle: string | null;
    }
    interface StripeIntegrationDetails {
        enabled: boolean | null;
        encryptedPublicKey: string | null;
        encryptedSecretKey: string | null;
    }
    interface StripeIntegrationStatus {
        publicKey: string | null;
        enabled: boolean | null;
        configured: boolean | null;
    }
    class IntegrationCredentialClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        credentialsGET(req: credentialsGETRequest): Promise<PaginatedResults<IntegrationCredential>>;
        private __credentialsGET;
        credentialTypesGET(req: credentialTypesGETRequest): Promise<PaginatedResults<IntegrationCredentialType>>;
        private __credentialTypesGET;
        credentialsSearchGET(req: credentialsSearchGETRequest): Promise<SearchResult[]>;
        private __credentialsSearchGET;
        credentialGET(req: credentialGETRequest): Promise<IntegrationCredential>;
        private __credentialGET;
        credentialPUT(req: credentialPUTRequest): Promise<IntegrationCredential>;
        private __credentialPUT;
        credentialPOST(req: credentialPOSTRequest): Promise<IntegrationCredential>;
        private __credentialPOST;
    }
    interface credentialsGETRequest {
        start?: string;
        limit?: number;
        showHidden?: boolean;
    }
    interface credentialTypesGETRequest {
        start?: string;
        limit?: number;
    }
    interface credentialsSearchGETRequest {
        text?: string;
    }
    interface credentialGETRequest {
        id?: string;
    }
    interface credentialPUTRequest {
        integrationCredential?: IntegrationCredentialBase;
    }
    interface credentialPOSTRequest {
        integrationCredential?: IntegrationCredential;
    }
    class SteamClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        steamPUT(req: steamPUTRequest): Promise<boolean>;
        private __steamPUT;
        steamStatusGET(req: steamStatusGETRequest): Promise<SteamIntegrationSummary>;
        private __steamStatusGET;
        steamGuardGET(req: steamGuardGETRequest): Promise<SteamGuardStatus>;
        private __steamGuardGET;
        steamGuardPUT(req: steamGuardPUTRequest): Promise<boolean>;
        private __steamGuardPUT;
        steamReimportPUT(req: steamReimportPUTRequest): Promise<boolean>;
        private __steamReimportPUT;
        steamErrormsgGET(req: steamErrormsgGETRequest): Promise<string>;
        private __steamErrormsgGET;
    }
    interface steamPUTRequest {
        steamAppId: string;
        publisherKey: string;
        publisherUsername: string;
        publisherPassword: string;
    }
    interface steamStatusGETRequest {
    }
    interface steamGuardGETRequest {
    }
    interface steamGuardPUTRequest {
        steamGuardCode: string;
    }
    interface steamReimportPUTRequest {
    }
    interface steamErrormsgGETRequest {
    }
    class SteamStateClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
    }
    class StripeClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        stripePUT(req: stripePUTRequest): Promise<boolean>;
        private __stripePUT;
        stripeDELETE(req: stripeDELETERequest): Promise<boolean>;
        private __stripeDELETE;
        stripeTogglePUT(req: stripeTogglePUTRequest): Promise<boolean>;
        private __stripeTogglePUT;
        stripeStatusGET(req: stripeStatusGETRequest): Promise<StripeIntegrationStatus>;
        private __stripeStatusGET;
    }
    interface stripePUTRequest {
        publicKey?: string;
        secretKey?: string;
    }
    interface stripeDELETERequest {
    }
    interface stripeTogglePUTRequest {
        enabled?: boolean;
    }
    interface stripeStatusGETRequest {
    }
}
export declare namespace Licensing {
    interface LicenseKeyPool {
        id: string | null;
        name: string | null;
        visible: boolean | null;
        description: string | null;
        availableKeys: number | null;
        reservedKeys: number | null;
        issuedKeys: number | null;
        activatedKeys: number | null;
    }
    interface LicenseKeyPoolSearchResult {
        id: string | null;
        name: string | null;
    }
    interface PoolInsertResults {
        newKeys: number | null;
        results: {
            [key: string]: string;
        } | null;
    }
    interface ReservedKey {
        licenseKeyPoolId: string | null;
        licenseKey: string | null;
        reservedForEmail: string | null;
        reservedOnDate: number | null;
    }
    interface IssuedKey {
        licenseKeyPoolId: string | null;
        licenseKey: string | null;
        issuedToEmail: string | null;
        issuedOnDate: number | null;
    }
    interface LicenseKey {
        key: string | null;
        licensePoolId: string | null;
        reservedForEmail: string | null;
        dateReservedUtc: moment.Moment | null;
        issuedToEmail: string | null;
        dateIssuedUtc: moment.Moment | null;
        notes: string | null;
        dateActivatedUtc: moment.Moment | null;
    }
    class LicenseKeyClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        poolsGET(req: poolsGETRequest): Promise<PaginatedResults<LicenseKeyPool>>;
        private __poolsGET;
        poolsSearchGET(req: poolsSearchGETRequest): Promise<LicenseKeyPoolSearchResult[]>;
        private __poolsSearchGET;
        poolGET(req: poolGETRequest): Promise<LicenseKeyPool>;
        private __poolGET;
        poolPUT(req: poolPUTRequest): Promise<LicenseKeyPool>;
        private __poolPUT;
        poolPOST(req: poolPOSTRequest): Promise<LicenseKeyPool>;
        private __poolPOST;
        keysPUT(req: keysPUTRequest): Promise<PoolInsertResults>;
        private __keysPUT;
        keysReservePUT(req: keysReservePUTRequest): Promise<ReservedKey>;
        private __keysReservePUT;
        keysIssuePUT(req: keysIssuePUTRequest): Promise<IssuedKey>;
        private __keysIssuePUT;
        keysByReservedEmailGET(req: keysByReservedEmailGETRequest): Promise<LicenseKey[]>;
        private __keysByReservedEmailGET;
        keysByIssuedEmailGET(req: keysByIssuedEmailGETRequest): Promise<LicenseKey[]>;
        private __keysByIssuedEmailGET;
    }
    interface poolsGETRequest {
        start?: string;
        limit?: number;
        showHidden?: boolean;
    }
    interface poolsSearchGETRequest {
        text?: string;
    }
    interface poolGETRequest {
        id?: string;
    }
    interface poolPUTRequest {
        name?: string;
        description?: string;
        visible?: boolean;
    }
    interface poolPOSTRequest {
        id?: string;
        name?: string;
        description?: string;
        visible?: boolean;
    }
    interface keysPUTRequest {
        id?: string;
        keys?: string[];
    }
    interface keysReservePUTRequest {
        poolId?: string;
        userEmail?: string;
    }
    interface keysIssuePUTRequest {
        poolId?: string;
        key?: string;
        userEmail?: string;
        notes?: string;
    }
    interface keysByReservedEmailGETRequest {
        poolId?: string;
        email?: string;
    }
    interface keysByIssuedEmailGETRequest {
        poolId?: string;
        email?: string;
    }
}
export declare namespace RevenueShare {
    interface PaginatedInvoices {
        next: string | null;
        moreResults: boolean;
        results: Invoice[];
    }
    interface Invoice {
        invoiceId: string | null;
        dateCreatedUtc: moment.Moment | null;
        invoiceNumber: string | null;
        notes: string | null;
        visible: boolean | null;
        invoicePostId: string | null;
        invoicePostedUtc: moment.Moment | null;
        invoicePostNotes: string | null;
        lineItems: InvoiceLineItem[] | null;
    }
    interface InvoiceLineItem {
        invoiceId: string | null;
        invoiceLineItemId: string | null;
        productId: string | null;
        productName: string | null;
        revenueRulesetIdOverride: string | null;
        amount: number | null;
        amountFractionalDivisor: number | null;
        grossAmount: number | null;
        grossAmountFractionalDivisor: number | null;
        currency: string | null;
        amountPaid: number | null;
        amountPaidFractionalDivisor: number | null;
        grossAmountPaid: number | null;
        grossAmountPaidFractionalDivisor: number | null;
        hasRevenueShareRulesetCopy: boolean | null;
    }
    interface InvoiceSearchResult {
        id: string | null;
        name: string | null;
    }
    interface PaginatedInvoicePayments {
        next: string | null;
        moreResults: boolean;
        results: InvoicePayment[];
    }
    interface InvoicePayment {
        paymentId: string | null;
        invoiceId: string | null;
        dateCreatedUtc: moment.Moment | null;
        paymentNumber: string | null;
        notes: string | null;
        invoicePostId: string | null;
        paymentPostId: string | null;
        paymentPostedUtc: moment.Moment | null;
        paymentPostNotes: string | null;
        lineItems: InvoicePaymentLineItem[] | null;
        archived: boolean | null;
        currentOperation: PaymentOperation | null;
        stripeEnabled: boolean | null;
        stripeDidPreAuth: boolean | null;
        updateSourceAmountFromStripe: boolean | null;
        stripeJson: any | null;
        decimalPlaces: number | null;
        fractionalRecipientId: string | null;
    }
    interface InvoicePaymentLineItem {
        paymentId: string | null;
        invoiceLineItemId: string | null;
        amount: number | null;
        amountFractionalDivisor: number | null;
        grossAmount: number | null;
        grossAmountFractionalDivisor: number | null;
        sourceAmount: number | null;
        sourceAmountFractionalDivisor: number | null;
        sourceCurrency: string | null;
        exchangeRate: number | null;
        stripeAmount: number | null;
        stripeAmountFractionalDivisor: number | null;
        stripeCurrency: string | null;
    }
    interface PaymentOperation {
        type: string | null;
        lastProcessedUtc: moment.Moment | null;
        percentComplete: number | null;
    }
    interface RecipientTransaction {
        transactionId: string | null;
        title: string | null;
        notes: string | null;
        postId: string | null;
        recipientId: string | null;
        recipientName: string | null;
        invoiceId: string | null;
        paymentId: string | null;
        amount: number | null;
        amountFractionalDivisor: number | null;
        currency: string | null;
        archived: boolean | null;
        taxTransactionId: string | null;
        taxTransactionForId: string | null;
        taxAmount: number | null;
        taxAmountFractionalDivisor: number | null;
        taxRecipientId: string | null;
    }
    interface PaginatedProducts {
        next: string | null;
        moreResults: boolean;
        results: Product[];
    }
    interface Product {
        id: string | null;
        name: string | null;
        description: string | null;
        visible: boolean | null;
        tags: {
            [key: string]: string;
        } | null;
        defaultRevenueShareRulesetId: string | null;
        dataCaptureProjectId: string | null;
    }
    interface ProductSearchResult {
        id: string | null;
        name: string | null;
    }
    interface ProjectProductIdPair {
        projectId: string | null;
        productId: string | null;
    }
    interface ProjectIndependentProduct {
        projectId: string | null;
        projectName: string | null;
        productId: string | null;
        productName: string | null;
    }
    interface PaginatedRecipients {
        next: string | null;
        moreResults: boolean;
        results: Recipient[];
    }
    interface Recipient {
        id: string | null;
        name: string | null;
        description: string | null;
        postDistributionTaxPercentage: number | null;
        startingBalance: number | null;
        trackBalanceAndPayments: boolean | null;
        visible: boolean | null;
        balances: RecipientBalance[] | null;
    }
    interface RecipientBalance {
        balance: number | null;
        balanceFractionalDivisor: number | null;
        currency: string | null;
    }
    interface RecipientSearchResult {
        id: string | null;
        name: string | null;
    }
    interface PaginatedRecipientTransactions {
        next: string | null;
        moreResults: boolean;
        results: RecipientTransaction[];
    }
    interface PaginatedRevenueShareRulesets {
        next: string | null;
        moreResults: boolean;
        results: RevenueShareRuleset[];
    }
    interface RevenueShareRuleset {
        id: string | null;
        name: string | null;
        description: string | null;
        ruleset: RevenueShareRulesetRule[] | null;
        visible: boolean | null;
    }
    interface RevenueShareRulesetRule {
        distributions: RevenueShareRulesetDistribution[] | null;
        sourceFilters: RevenueShareRulesetSourceFilter[] | null;
    }
    interface RevenueShareRulesetDistribution {
        recipientId: string | null;
        percentageAmount: number | null;
        fixedAmount: number | null;
        fixedAmountFractionalDivisor: number | null;
        fractionalAmountNumerator: number | null;
        fractionalAmountDenominator: number | null;
        paymentLimit: number | null;
        distributeFromSourceAmount: boolean | null;
        distributeFromGrossAmount: boolean | null;
    }
    interface RevenueShareRulesetSourceFilter {
        name: string | null;
        value: string | null;
    }
    interface RevenueShareRulesetSearchResult {
        id: string | null;
        name: string | null;
    }
    interface SimulatedPayment {
        recipientId: string | null;
        recipientName: string | null;
        amount: number | null;
        currency: string | null;
        isFractionalLoss: boolean | null;
    }
    interface InvoicePaymentStripeStatus {
        isStripeAvailable: boolean | null;
        isStripeEnabled: boolean | null;
        isUnpaid: boolean | null;
        isPaid: boolean | null;
        isWaived: boolean | null;
        isCurrencySupported: boolean | null;
        currenciesSupported: string[] | null;
        hasMultipleCurrencies: boolean | null;
        publicPaymentLink: string | null;
    }
    interface PublicInvoicePayment {
        paymentNumber: string | null;
        notes: string | null;
        isStripeEnabled: boolean | null;
        isUnpaid: boolean | null;
        isPaid: boolean | null;
        isWaived: boolean | null;
        isCurrencySupported: boolean | null;
        hasMultipleCurrencies: boolean | null;
        canPay: boolean | null;
        stripePublicKey: string | null;
        stripeAmount: number | null;
        stripeCurrency: string | null;
        lineItems: PublicInvoicePaymentLineItem[] | null;
        totalAmount: string | null;
        totalCurrency: string | null;
    }
    interface PublicInvoicePaymentLineItem {
        name: string | null;
        amount: string | null;
    }
    class InvoiceClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        invoicesGET(req: invoicesGETRequest): Promise<PaginatedInvoices>;
        private __invoicesGET;
        invoicesSearchGET(req: invoicesSearchGETRequest): Promise<InvoiceSearchResult[]>;
        private __invoicesSearchGET;
        invoiceGET(req: invoiceGETRequest): Promise<Invoice>;
        private __invoiceGET;
        invoicePUT(req: invoicePUTRequest): Promise<Invoice>;
        private __invoicePUT;
        invoicePOST(req: invoicePOSTRequest): Promise<Invoice>;
        private __invoicePOST;
        invoicePostPUT(req: invoicePostPUTRequest): Promise<Invoice>;
        private __invoicePostPUT;
        invoiceUnpostPUT(req: invoiceUnpostPUTRequest): Promise<Invoice>;
        private __invoiceUnpostPUT;
        invoiceItemPUT(req: invoiceItemPUTRequest): Promise<InvoiceLineItem>;
        private __invoiceItemPUT;
        invoiceItemPOST(req: invoiceItemPOSTRequest): Promise<InvoiceLineItem>;
        private __invoiceItemPOST;
        invoiceItemDELETE(req: invoiceItemDELETERequest): Promise<boolean>;
        private __invoiceItemDELETE;
        invoicePaymentsGET(req: invoicePaymentsGETRequest): Promise<PaginatedInvoicePayments>;
        private __invoicePaymentsGET;
        invoicePaymentGET(req: invoicePaymentGETRequest): Promise<InvoicePayment>;
        private __invoicePaymentGET;
        invoicePaymentPUT(req: invoicePaymentPUTRequest): Promise<InvoicePayment>;
        private __invoicePaymentPUT;
        invoicePaymentPOST(req: invoicePaymentPOSTRequest): Promise<InvoicePayment>;
        private __invoicePaymentPOST;
        invoicePaymentTransactionsGET(req: invoicePaymentTransactionsGETRequest): Promise<RecipientTransaction[]>;
        private __invoicePaymentTransactionsGET;
        invoicePaymentPostPUT(req: invoicePaymentPostPUTRequest): Promise<InvoicePayment>;
        private __invoicePaymentPostPUT;
        invoicePaymentUnpostPUT(req: invoicePaymentUnpostPUTRequest): Promise<InvoicePayment>;
        private __invoicePaymentUnpostPUT;
        invoicePaymentProcessPUT(req: invoicePaymentProcessPUTRequest): Promise<boolean>;
        private __invoicePaymentProcessPUT;
        invoicePaymentProgressGET(req: invoicePaymentProgressGETRequest): Promise<PaymentOperation>;
        private __invoicePaymentProgressGET;
        invoicePaymentRequeuePUT(req: invoicePaymentRequeuePUTRequest): Promise<boolean>;
        private __invoicePaymentRequeuePUT;
    }
    interface invoicesGETRequest {
        start?: string;
        limit?: number;
        showHidden?: boolean;
    }
    interface invoicesSearchGETRequest {
        text?: string;
    }
    interface invoiceGETRequest {
        invoiceId?: string;
    }
    interface invoicePUTRequest {
        invoiceNumber?: string;
        notes?: string;
        visible?: boolean;
    }
    interface invoicePOSTRequest {
        invoiceId?: string;
        invoiceNumber?: string;
        notes?: string;
        visible?: boolean;
    }
    interface invoicePostPUTRequest {
        invoiceId?: string;
        postNotes?: string;
    }
    interface invoiceUnpostPUTRequest {
        invoiceId?: string;
    }
    interface invoiceItemPUTRequest {
        invoiceId?: string;
        productId?: string;
        revenueRulesetIdOverride?: string;
        amount?: number;
        amountFractionalDivisor?: number;
        grossAmount?: number;
        grossAmountFractionalDivisor?: number;
        currency?: string;
    }
    interface invoiceItemPOSTRequest {
        invoiceId?: string;
        invoiceLineItemId?: string;
        productId?: string;
        revenueRulesetIdOverride?: string;
        amount?: number;
        amountFractionalDivisor?: number;
        grossAmount?: number;
        grossAmountFractionalDivisor?: number;
        currency?: string;
    }
    interface invoiceItemDELETERequest {
        invoiceId?: string;
        invoiceLineItemId?: string;
    }
    interface invoicePaymentsGETRequest {
        invoiceId?: string;
        start?: string;
        limit?: number;
    }
    interface invoicePaymentGETRequest {
        paymentId?: string;
    }
    interface invoicePaymentPUTRequest {
        invoiceId?: string;
        paymentNumber?: string;
        notes?: string;
        decimalPlaces?: number;
        fractionalRecipientId?: string;
        lineItems?: InvoicePaymentLineItem[];
    }
    interface invoicePaymentPOSTRequest {
        paymentId?: string;
        paymentNumber?: string;
        notes?: string;
        decimalPlaces?: number;
        fractionalRecipientId?: string;
        lineItems?: InvoicePaymentLineItem[];
    }
    interface invoicePaymentTransactionsGETRequest {
        paymentId?: string;
    }
    interface invoicePaymentPostPUTRequest {
        paymentId?: string;
        postNotes?: string;
    }
    interface invoicePaymentUnpostPUTRequest {
        paymentId?: string;
    }
    interface invoicePaymentProcessPUTRequest {
        paymentId?: string;
    }
    interface invoicePaymentProgressGETRequest {
        paymentId?: string;
    }
    interface invoicePaymentRequeuePUTRequest {
        paymentId?: string;
    }
    class ProductClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        productsGET(req: productsGETRequest): Promise<PaginatedProducts>;
        private __productsGET;
        productsSearchGET(req: productsSearchGETRequest): Promise<ProductSearchResult[]>;
        private __productsSearchGET;
        productGET(req: productGETRequest): Promise<Product>;
        private __productGET;
        productPUT(req: productPUTRequest): Promise<Product>;
        private __productPUT;
        productPOST(req: productPOSTRequest): Promise<Product>;
        private __productPOST;
    }
    interface productsGETRequest {
        start?: string;
        limit?: number;
        showHidden?: boolean;
    }
    interface productsSearchGETRequest {
        text?: string;
    }
    interface productGETRequest {
        id?: string;
    }
    interface productPUTRequest {
        name?: string;
        description?: string;
        visible?: boolean;
        tags?: any;
        defaultRevenueShareRulesetId?: string;
        dataCaptureProjectId?: string;
    }
    interface productPOSTRequest {
        id?: string;
        name?: string;
        description?: string;
        visible?: boolean;
        tags?: any;
        defaultRevenueShareRulesetId?: string;
        dataCaptureProjectId?: string;
    }
    class RecipientClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        recipientsGET(req: recipientsGETRequest): Promise<PaginatedRecipients>;
        private __recipientsGET;
        recipientsSearchGET(req: recipientsSearchGETRequest): Promise<RecipientSearchResult[]>;
        private __recipientsSearchGET;
        recipientGET(req: recipientGETRequest): Promise<Recipient>;
        private __recipientGET;
        recipientPUT(req: recipientPUTRequest): Promise<Recipient>;
        private __recipientPUT;
        recipientPOST(req: recipientPOSTRequest): Promise<Recipient>;
        private __recipientPOST;
        recipientTransactionsGET(req: recipientTransactionsGETRequest): Promise<PaginatedRecipientTransactions>;
        private __recipientTransactionsGET;
        recipientTransactionGET(req: recipientTransactionGETRequest): Promise<RecipientTransaction>;
        private __recipientTransactionGET;
        recipientTransactionPUT(req: recipientTransactionPUTRequest): Promise<RecipientTransaction>;
        private __recipientTransactionPUT;
        recipientTransactionDELETE(req: recipientTransactionDELETERequest): Promise<RecipientTransaction>;
        private __recipientTransactionDELETE;
    }
    interface recipientsGETRequest {
        start?: string;
        limit?: number;
        showHidden?: boolean;
    }
    interface recipientsSearchGETRequest {
        text?: string;
    }
    interface recipientGETRequest {
        id?: string;
    }
    interface recipientPUTRequest {
        name?: string;
        description?: string;
        postDistributionTaxPercentage?: number;
        startingBalance?: number;
        trackBalanceAndPayments?: boolean;
        visible?: boolean;
    }
    interface recipientPOSTRequest {
        id?: string;
        name?: string;
        description?: string;
        postDistributionTaxPercentage?: number;
        startingBalance?: number;
        trackBalanceAndPayments?: boolean;
        visible?: boolean;
    }
    interface recipientTransactionsGETRequest {
        recipientId?: string;
        start?: string;
        limit?: number;
        showHidden?: boolean;
    }
    interface recipientTransactionGETRequest {
        transactionId?: string;
    }
    interface recipientTransactionPUTRequest {
        recipientId?: string;
        title?: string;
        notes?: string;
        amount?: number;
        amountFractionalDivisor?: number;
        currency?: string;
        generateTaxTransaction?: boolean;
        taxAmount?: number;
        taxAmountFractionalDivisor?: number;
        taxRecipientId?: string;
    }
    interface recipientTransactionDELETERequest {
        transactionId?: string;
    }
    class RevenueShareRulesetClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        rulesetsGET(req: rulesetsGETRequest): Promise<PaginatedRevenueShareRulesets>;
        private __rulesetsGET;
        rulesetsSearchGET(req: rulesetsSearchGETRequest): Promise<RevenueShareRulesetSearchResult[]>;
        private __rulesetsSearchGET;
        rulesetGET(req: rulesetGETRequest): Promise<RevenueShareRuleset>;
        private __rulesetGET;
        rulesetPUT(req: rulesetPUTRequest): Promise<RevenueShareRuleset>;
        private __rulesetPUT;
        rulesetPOST(req: rulesetPOSTRequest): Promise<RevenueShareRuleset>;
        private __rulesetPOST;
        rulesetSimulatePUT(req: rulesetSimulatePUTRequest): Promise<SimulatedPayment[]>;
        private __rulesetSimulatePUT;
    }
    interface rulesetsGETRequest {
        start?: string;
        limit?: number;
        showHidden?: boolean;
    }
    interface rulesetsSearchGETRequest {
        text?: string;
    }
    interface rulesetGETRequest {
        id?: string;
    }
    interface rulesetPUTRequest {
        name?: string;
        description?: string;
        ruleset?: RevenueShareRulesetRule[];
        visible?: boolean;
    }
    interface rulesetPOSTRequest {
        id?: string;
        name?: string;
        description?: string;
        ruleset?: RevenueShareRulesetRule[];
        visible?: boolean;
    }
    interface rulesetSimulatePUTRequest {
        productId?: string;
        amount?: number;
        currency?: string;
        sourceAmount?: number;
        sourceCurrency?: string;
        decimalPlaces?: number;
        rulesetJson?: RevenueShareRulesetRule[];
    }
    class StripeClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        stripePaymentEnabledPOST(req: stripePaymentEnabledPOSTRequest): Promise<boolean>;
        private __stripePaymentEnabledPOST;
        stripePaymentStatusGET(req: stripePaymentStatusGETRequest): Promise<InvoicePaymentStripeStatus>;
        private __stripePaymentStatusGET;
        stripePaymentGET(req: stripePaymentGETRequest): Promise<PublicInvoicePayment>;
        private __stripePaymentGET;
        stripePaymentPUT(req: stripePaymentPUTRequest): Promise<boolean>;
        private __stripePaymentPUT;
    }
    interface stripePaymentEnabledPOSTRequest {
        paymentId?: string;
        enabled?: boolean;
    }
    interface stripePaymentStatusGETRequest {
        paymentId?: string;
    }
    interface stripePaymentGETRequest {
        paymentToken?: string;
    }
    interface stripePaymentPUTRequest {
        paymentToken?: string;
        stripeToken?: string;
    }
}
export declare namespace Reporting {
    interface BigQueryAccess {
        googleAccountEmail: string | null;
        privateBigQueryDatasetName: string | null;
        publicBigQueryDatasetName: string | null;
        bigQueryProjectName: string | null;
    }
    interface PaginatedBigQueryAccesses {
        next: string | null;
        moreResults: boolean;
        results: BigQueryAccess[];
    }
    interface TimeSeriesData {
        timeBegin: number | null;
        timeEnd: number | null;
        dataGroups: DataGroup[] | null;
        dataPoints: {
            [key: string]: TimeSeriesDataPoint[];
        } | null;
    }
    interface DataGroup {
        groupName: string | null;
        preferredColor: string | null;
    }
    interface TimeSeriesDataPoint {
        integerValue: number | null;
        percentValue: number | null;
        currencyUsdValue: number | null;
    }
    interface PaginatedReportMetadatas {
        next: string | null;
        moreResults: boolean;
        results: ReportMetadata[];
    }
    interface ReportMetadata {
        id: string | null;
        available: boolean | null;
        title: string | null;
        shortDescription: string | null;
        category: string | null;
        type: string | null;
        parameters: ReportParameter[] | null;
    }
    interface ReportParameter {
        id: string | null;
        name: string | null;
        helpText: string | null;
        type: string | null;
        objectType: string | null;
        showTimeValues: boolean | null;
        required: boolean | null;
        enabled: boolean | null;
        defaultSpecial: string | null;
        defaultText: string | null;
        defaultInteger: number | null;
        defaultFloat: number | null;
        defaultBoolean: boolean | null;
    }
    interface ReportData {
        metadata: ReportMetadata | null;
        timeSeriesData: TimeSeriesData | null;
        rangeSeriesData: RangeSeriesData | null;
        invoiceData: InvoiceData | null;
        cachedResults: boolean | null;
    }
    interface RangeSeriesData {
        rangeBegin: number | null;
        rangeEnd: number | null;
        rangeTitle: string | null;
        dataGroups: DataGroup[] | null;
        dataPoints: {
            [key: string]: RangeSeriesDataPoint[];
        } | null;
    }
    interface InvoiceData {
        notFound: boolean | null;
        name: string | null;
        notes: string | null;
        periodStartUtc: moment.Moment | null;
        periodEndUtc: moment.Moment | null;
        startingBalances: InvoiceLineItemData[] | null;
        endingBalances: InvoiceLineItemData[] | null;
        lineItems: InvoiceLineItemData[] | null;
    }
    interface RangeSeriesDataPoint {
        integerValue: number | null;
        percentValue: number | null;
        currencyUsdValue: number | null;
    }
    interface InvoiceLineItemData {
        dateUtc: moment.Moment | null;
        description: string | null;
        amount: number | null;
        amountFractionalDivisor: number | null;
        currency: string | null;
    }
    interface ReportArgument {
        id: string | null;
        valueObjectId: string | null;
        valueText: string | null;
        valueInteger: number | null;
        valueFloat: number | null;
        valueTimestamp: number | null;
        valueTimestampRangeBegin: number | null;
        valueTimestampRangeEnd: number | null;
        valueBoolean: boolean | null;
    }
    class BigQueryAccessClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        bigqueryAccessPUT(req: bigqueryAccessPUTRequest): Promise<BigQueryAccess>;
        private __bigqueryAccessPUT;
        bigqueryAccessDELETE(req: bigqueryAccessDELETERequest): Promise<BigQueryAccess>;
        private __bigqueryAccessDELETE;
        bigqueryProjectAccessGET(req: bigqueryProjectAccessGETRequest): Promise<PaginatedBigQueryAccesses>;
        private __bigqueryProjectAccessGET;
    }
    interface bigqueryAccessPUTRequest {
        accountEmail: string;
    }
    interface bigqueryAccessDELETERequest {
        accountEmail: string;
    }
    interface bigqueryProjectAccessGETRequest {
        start?: string;
        limit?: number;
    }
    class BuiltinReportsClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        builtinVisitsWishlistsGET(req: builtinVisitsWishlistsGETRequest): Promise<TimeSeriesData>;
        private __builtinVisitsWishlistsGET;
        builtinVisitsActionsGET(req: builtinVisitsActionsGETRequest): Promise<TimeSeriesData>;
        private __builtinVisitsActionsGET;
        builtinVisitsActionsConversionGET(req: builtinVisitsActionsConversionGETRequest): Promise<TimeSeriesData>;
        private __builtinVisitsActionsConversionGET;
        builtinWishlistActionsGET(req: builtinWishlistActionsGETRequest): Promise<TimeSeriesData>;
        private __builtinWishlistActionsGET;
        builtinVisitsBreakdownDetailedGET(req: builtinVisitsBreakdownDetailedGETRequest): Promise<TimeSeriesData>;
        private __builtinVisitsBreakdownDetailedGET;
        builtinVisitsBreakdownPageGET(req: builtinVisitsBreakdownPageGETRequest): Promise<TimeSeriesData>;
        private __builtinVisitsBreakdownPageGET;
        builtinSalesUnitBreakdownSourceGET(req: builtinSalesUnitBreakdownSourceGETRequest): Promise<TimeSeriesData>;
        private __builtinSalesUnitBreakdownSourceGET;
        builtinSalesUnitBreakdownSteamGET(req: builtinSalesUnitBreakdownSteamGETRequest): Promise<TimeSeriesData>;
        private __builtinSalesUnitBreakdownSteamGET;
        builtinSalesUnitBreakdownRetailGET(req: builtinSalesUnitBreakdownRetailGETRequest): Promise<TimeSeriesData>;
        private __builtinSalesUnitBreakdownRetailGET;
        builtinSalesUsdBreakdownSourceGET(req: builtinSalesUsdBreakdownSourceGETRequest): Promise<TimeSeriesData>;
        private __builtinSalesUsdBreakdownSourceGET;
        builtinSalesUsdBreakdownSteamGET(req: builtinSalesUsdBreakdownSteamGETRequest): Promise<TimeSeriesData>;
        private __builtinSalesUsdBreakdownSteamGET;
    }
    interface builtinVisitsWishlistsGETRequest {
        start?: number;
        end?: number;
        intervalAmount?: number;
        intervalUnits?: string;
    }
    interface builtinVisitsActionsGETRequest {
        start?: number;
        end?: number;
        intervalAmount?: number;
        intervalUnits?: string;
    }
    interface builtinVisitsActionsConversionGETRequest {
        start?: number;
        end?: number;
        intervalAmount?: number;
        intervalUnits?: string;
    }
    interface builtinWishlistActionsGETRequest {
        start?: number;
        end?: number;
        intervalAmount?: number;
        intervalUnits?: string;
    }
    interface builtinVisitsBreakdownDetailedGETRequest {
        start?: number;
        end?: number;
        intervalAmount?: number;
        intervalUnits?: string;
    }
    interface builtinVisitsBreakdownPageGETRequest {
        start?: number;
        end?: number;
        intervalAmount?: number;
        intervalUnits?: string;
    }
    interface builtinSalesUnitBreakdownSourceGETRequest {
        start?: number;
        end?: number;
        intervalAmount?: number;
        intervalUnits?: string;
    }
    interface builtinSalesUnitBreakdownSteamGETRequest {
        start?: number;
        end?: number;
        intervalAmount?: number;
        intervalUnits?: string;
    }
    interface builtinSalesUnitBreakdownRetailGETRequest {
        start?: number;
        end?: number;
        intervalAmount?: number;
        intervalUnits?: string;
    }
    interface builtinSalesUsdBreakdownSourceGETRequest {
        start?: number;
        end?: number;
        intervalAmount?: number;
        intervalUnits?: string;
    }
    interface builtinSalesUsdBreakdownSteamGETRequest {
        start?: number;
        end?: number;
        intervalAmount?: number;
        intervalUnits?: string;
    }
    class ReportClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        reportsGET(req: reportsGETRequest): Promise<PaginatedReportMetadatas>;
        private __reportsGET;
        reportGET(req: reportGETRequest): Promise<ReportData>;
        private __reportGET;
        reportMetadataGET(req: reportMetadataGETRequest): Promise<ReportMetadata>;
        private __reportMetadataGET;
        reportRunPUT(req: reportRunPUTRequest): Promise<ReportData>;
        private __reportRunPUT;
    }
    interface reportsGETRequest {
        start?: string;
        limit?: number;
    }
    interface reportGETRequest {
        id?: string;
        start?: number;
        end?: number;
        parameters?: any;
    }
    interface reportMetadataGETRequest {
        id?: string;
    }
    interface reportRunPUTRequest {
        id?: string;
        disableCache?: boolean;
        arguments?: ReportArgument[];
    }
}
export declare namespace GameServer {
    interface GameServer {
        id: string | null;
        gameServerTemplateId: string | null;
        gameServerTemplateCachedName: string | null;
        gameServerClusterId: string | null;
        imagePullIntegrationCredentialId: string | null;
        version: string | null;
        billedSliceMinutes: number | null;
        resources: number | null;
        status: string | null;
        serverIpAddress: string | null;
        serverPorts: GameServerPortMapping[] | null;
        dateCreatedUtc: moment.Moment | null;
        dateBillingStartUtc: moment.Moment | null;
        dateBillingEndUtc: moment.Moment | null;
        dateExpiresUtc: moment.Moment | null;
    }
    interface GameServerPortMapping {
        type: string | null;
        port: number | null;
        publicPort: number | null;
    }
    interface GameServerPublic {
        id: string | null;
        status: string | null;
        serverIpAddress: string | null;
        serverPorts: GameServerPortMapping[] | null;
    }
    interface GameServerProvisioningRequest {
        templateId: string | null;
        gameServerClusterId: string | null;
        version: string | null;
    }
    interface GameServerCluster {
        id: string | null;
        name: string | null;
        description: string | null;
        enabled: boolean | null;
        visible: boolean | null;
        integrationCredentialId: string | null;
        kubernetesNamespace: string | null;
        remoteAgentSecretToken: string | null;
    }
    interface SearchResult {
        id: string | null;
        name: string | null;
    }
    interface GameServerClusterBase {
        name: string | null;
        description: string | null;
        enabled: boolean | null;
        visible: boolean | null;
        integrationCredentialId: string | null;
        kubernetesNamespace: string | null;
        remoteAgentSecretToken: string | null;
    }
    interface PodNotifyMessage {
        gsid: string | null;
    }
    interface GameServerTemplate {
        id: string | null;
        name: string | null;
        dockerImageName: string | null;
        imagePullIntegrationCredentialId: string | null;
        resources: number | null;
        ports: GameServerPortSpec[] | null;
    }
    interface GameServerPortSpec {
        type: string | null;
        port: number | null;
    }
    interface GameServerTemplateBase {
        name: string | null;
        dockerImageName: string | null;
        imagePullIntegrationCredentialId: string | null;
        resources: number | null;
        ports: GameServerPortSpec[] | null;
    }
    class GameServerClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        serversGET(req: serversGETRequest): Promise<PaginatedResults<GameServer>>;
        private __serversGET;
        serverGET(req: serverGETRequest): Promise<GameServer>;
        private __serverGET;
        serverPublicGET(req: serverPublicGETRequest): Promise<GameServerPublic>;
        private __serverPublicGET;
        terminateDELETE(req: terminateDELETERequest): Promise<GameServer>;
        private __terminateDELETE;
        provisionPUT(req: provisionPUTRequest): Promise<GameServer>;
        private __provisionPUT;
    }
    interface serversGETRequest {
        start?: string;
        limit?: number;
    }
    interface serverGETRequest {
        id?: string;
    }
    interface serverPublicGETRequest {
        id?: string;
    }
    interface terminateDELETERequest {
        id?: string;
    }
    interface provisionPUTRequest {
        provisioningRequest?: GameServerProvisioningRequest;
    }
    class GameServerClusterClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        clustersGET(req: clustersGETRequest): Promise<PaginatedResults<GameServerCluster>>;
        private __clustersGET;
        clustersSearchGET(req: clustersSearchGETRequest): Promise<SearchResult[]>;
        private __clustersSearchGET;
        clusterGET(req: clusterGETRequest): Promise<GameServerCluster>;
        private __clusterGET;
        clusterPUT(req: clusterPUTRequest): Promise<GameServerCluster>;
        private __clusterPUT;
        clusterPOST(req: clusterPOSTRequest): Promise<GameServerCluster>;
        private __clusterPOST;
        clusterDELETE(req: clusterDELETERequest): Promise<GameServerCluster>;
        private __clusterDELETE;
    }
    interface clustersGETRequest {
        start?: string;
        limit?: number;
        showHidden?: boolean;
    }
    interface clustersSearchGETRequest {
        text?: string;
    }
    interface clusterGETRequest {
        id?: string;
    }
    interface clusterPUTRequest {
        cluster?: GameServerClusterBase;
    }
    interface clusterPOSTRequest {
        cluster?: GameServerCluster;
    }
    interface clusterDELETERequest {
        id?: string;
    }
    class GameServerNotifyClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        kubernetesNotifyGET(req: kubernetesNotifyGETRequest): Promise<void>;
        private __kubernetesNotifyGET;
    }
    interface kubernetesNotifyGETRequest {
        projectId?: string;
        clusterId?: string;
        clusterSecretToken?: string;
    }
    class GameServerTemplateClient implements IHiveMPClient {
        /**
         * The method that returns the API key to use in the request.
         */
        apiKeyFactory: () => string;
        /**
         * The base URL factory for requests.
         */
        baseUrlFactory: () => string;
        /**
         * The invocation wrapper that is called around every API method.
         */
        invocationWrapper: HiveMPInvocationWrapper<any> | null;
        getOriginalApiId: () => string;
        getOriginalBasePath: () => string;
        constructor(apiKey?: (string | (() => string)));
        templatesGET(req: templatesGETRequest): Promise<PaginatedResults<GameServerTemplate>>;
        private __templatesGET;
        templatesSearchGET(req: templatesSearchGETRequest): Promise<SearchResult[]>;
        private __templatesSearchGET;
        templateGET(req: templateGETRequest): Promise<GameServerTemplate>;
        private __templateGET;
        templatePUT(req: templatePUTRequest): Promise<GameServerTemplate>;
        private __templatePUT;
        templatePOST(req: templatePOSTRequest): Promise<GameServerTemplate>;
        private __templatePOST;
        templateDELETE(req: templateDELETERequest): Promise<GameServerTemplate>;
        private __templateDELETE;
    }
    interface templatesGETRequest {
        start?: string;
        limit?: number;
    }
    interface templatesSearchGETRequest {
        text?: string;
    }
    interface templateGETRequest {
        id?: string;
    }
    interface templatePUTRequest {
        template?: GameServerTemplateBase;
    }
    interface templatePOSTRequest {
        template?: GameServerTemplate;
    }
    interface templateDELETERequest {
        id?: string;
    }
}
